import React, { useState, useEffect } from "react";
import { Swiper, SwiperSlide } from "swiper/react";
import "swiper/css";
import "swiper/css/navigation";
import { Navigation } from "swiper/modules";
import { toast } from "react-toastify";

const Hero = () => {
  const [images, setImages] = useState(() => {
    try {
      const savedImages = localStorage.getItem("heroImages");
      return savedImages ? JSON.parse(savedImages) : [];
    } catch (error) {
      console.error("Error accessing localStorage", error);
      return [];
    }
  });

  // Save images to localStorage
  useEffect(() => {
    if (images.length > 0) {
      try {
        localStorage.setItem("heroImages", JSON.stringify(images));
      } catch (error) {
        console.error("Error saving images to localStorage", error);
      }
    }
  }, [images]);

  const handleAddImage = (event) => {
    const file = event.target.files[0];
    if (file) {
      const reader = new FileReader();
      reader.onload = (e) => {
        setImages([e.target.result, ...images]);
        toast.success("Image added successfully!");
      };
      reader.readAsDataURL(file);
    }
  };

  const handleUpdateImage = (index) => {
    const fileInput = document.createElement("input");
    fileInput.type = "file";
    fileInput.accept = "image/*";
    fileInput.onchange = (event) => {
      const file = event.target.files[0];
      if (file) {
        const reader = new FileReader();
        reader.onload = (e) => {
          const updatedImages = [...images];
          updatedImages[index] = e.target.result;
          setImages(updatedImages);
          toast.success("Image updated successfully!");
        };
        reader.readAsDataURL(file);
      }
    };
    fileInput.click();
  };

  const handleRemoveImage = (index) => {
    const updatedImages = images.filter((_, i) => i !== index);
    setImages(updatedImages);
    toast.success("Image removed successfully!");
  };

  return (
    <div>
      {images.length > 0 ? (
        <Swiper
          modules={[Navigation]}
          navigation
          loop={true}
          spaceBetween={10}
          slidesPerView={1}
        >
          {images.map((image, index) => (
            <SwiperSlide key={index} className="relative">
              <img
                src={image}
                alt={`Slide ${index + 1}`}
                className="w-full object-cover h-[300px] md:h-[350px] lg:h-[600px]"
              />
              <div className="flex items-center space-x-2">
                <button
                  onClick={() => handleUpdateImage(index)}
                  className="absolute top-4 right-4 bg-blue-500 text-white px-2 py-1 md:px-4 md:py-2 rounded-full hover:bg-blue-600 cursor-pointer"
                >
                  Update
                </button>
                <button
                  onClick={() => handleRemoveImage(index)}
                  className="absolute top-4 right-24 bg-red-500 mr-3 md:mr-6 text-white px-2 py-1 md:px-4 md:py-2 rounded-full hover:bg-red-600 cursor-pointer"
                >
                  Remove
                </button>
              </div>
            </SwiperSlide>
          ))}
        </Swiper>
      ) : (
        <p className="text-center text-gray-500 mt-4">
          No images available. Please add one.
        </p>
      )}

      <div className="flex items-center space-x-2 mt-3">
        <input
          type="file"
          accept="image/*"
          onChange={handleAddImage}
          className="hidden"
          id="fileInput"
        />
        <label
          htmlFor="fileInput"
          className="bg-white text-black px-4 py-2 rounded-lg hover:bg-gray-300 cursor-pointer"
        >
          Add Image
        </label>
      </div>
    </div>
  );
};

export default Hero;
